oauthkit-google
===============

OAuthKit for Google


Development environment
-----------------------

To setup development environment::

   virtualenv -p python2.7 .
   bin/pip install -U setuptools pip pip-tools
   make
   make test
